cheesecake.logger

Package cheesecake :: Module logger |
[show private | hide private]
[frames | no frames]

## Module cheesecake.logger

Classes
`File` |
`Message` |
`MultipleProducer` |
`Path` |
`Producer` | Log producer API which sends messages to be logged to a 'consumer' object, which then prints them to stdout, stderr, files, etc.

Function Summary
| `default_consumer(msg)`
| `setconsumer(keywords, consumer)`
| `STDERR(msg)`
| `STDOUT(msg)`

Variable Summary
`Producer` | `default` = `<Producer default>`

Variable Details

    ### default Type: `Producer` Value:
        <Producer default>

Generated by Epydoc 2.1 on Fri Feb 9 02:15:12 2007 | http://epydoc.sf.net